@@ -7,9 +7,6 @@ class AnimeXtremistCom(Provider, Std):
     helper = None
     prefix = '/mangas-online/'
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index())
-
     def get_chapter_index(self) -> str:
         chapter = self.chapter
         idx = self.re.search(r'(.+?-\d+)', chapter[0])
