@@ -92,5 +92,8 @@ class DanbooruDonmaiUs(Provider, Std):
         # todo meta
         pass
 
+    def chapter_for_json(self):
+        return self.get_url()
+
 
 main = DanbooruDonmaiUs
