@@ -14,11 +14,7 @@ class KomikIdCom(GoMangaCo, Std):
 
     def get_files(self):
         parser = self.html_fromstring(self.chapter)
-        if ~self.get_url().find('mangaid.'):
-            items = self._images_helper(parser, '#all img.img-responsive')
-        else:
-            items = self._images_helper(parser, '#all img[data-src]', 'data-src')
-        return [i.strip(' \n\r\t\0') for i in items]
+        return self._images_helper(parser, '#all img[data-src]', 'data-src')
 
     def get_cover(self) -> str:
         return self._cover_from_content('.boxed img')
