@@ -26,7 +26,7 @@ class ManhuaTaiCom(Provider, Std):
         return self._get_content('{}/{}/')
 
     def get_manga_name(self) -> str:
-        return self._get_name(r'\.com/([^/]+)')
+        return self._get_name(r'\.\w{2,7}/([^/]+)')
 
     def get_chapters(self):
         topics = self._elements('[id^=topic]')
